searchData={"items":[{"type":"module","title":"Kadabra","doc":"HTTP/2 client for Elixir.\n\nWritten to manage HTTP/2 connections for\n[pigeon](https://github.com/codedge-llc/pigeon).\n\n*Requires Elixir 1.4/OTP 19.2 or later.*","ref":"Kadabra.html"},{"type":"module","title":"Usage - Kadabra","doc":"{:ok, pid} = Kadabra.open(\"https://http2.codedge.dev\")\n    Kadabra.get(pid, \"/\")\n    receive do\n      {:end_stream, %Kadabra.Stream.Response{} = stream} ->\n      IO.inspect stream\n    after 5_000 ->\n      IO.puts \"Connection timed out.\"\n    end\n\n    %Kadabra.Stream.Response{\n      body: \"GET OK\"\n      headers: [\n        {\":status\", \"200\"},\n        {\"content-type\", \"text/html; charset=utf-8\"},\n        {\"content-length\", \"1708\"},\n        {\"date\", \"Sun, 16 Oct 2016 21:20:47 GMT\"}\n      ],\n      id: 1,\n      status: 200\n    }","ref":"Kadabra.html#module-usage"},{"type":"module","title":"Making Requests Manually - Kadabra","doc":"{:ok, pid} = Kadabra.open(\"https://http2.codedge.dev\")\n\n    path = \"/ECHO\" # Route echoes PUT body in uppercase\n    body = \"sample echo request\"\n    headers = [\n      {\":method\", \"PUT\"},\n      {\":path\", path},\n    ]\n\n    Kadabra.request(pid, headers, body)\n\n    receive do\n      {:end_stream, %Kadabra.Stream.Response{} = stream} ->\n      IO.inspect stream\n    after 5_000 ->\n      IO.puts \"Connection timed out.\"\n    end\n\n    %Kadabra.Stream.Response{\n      body: \"SAMPLE ECHO REQUEST\",\n      headers: [\n        {\":status\", \"200\"},\n        {\"content-type\", \"text/plain; charset=utf-8\"},\n        {\"date\", \"Sun, 16 Oct 2016 21:28:15 GMT\"}\n      ],\n      id: 1,\n      status: 200\n    }","ref":"Kadabra.html#module-making-requests-manually"},{"type":"function","title":"Kadabra.close/1","doc":"Closes an existing connection.","ref":"Kadabra.html#close/1"},{"type":"function","title":"Examples - Kadabra.close/1","doc":"iex> {:ok, pid} = Kadabra.open(\"https://http2.codedge.dev\")\n    iex> Kadabra.close(pid)\n    iex> receive do\n    ...>   {:closed, _pid} -> \"connection closed!\"\n    ...> end\n    \"connection closed!\"","ref":"Kadabra.html#close/1-examples"},{"type":"function","title":"Kadabra.delete/3","doc":"Makes a DELETE request.","ref":"Kadabra.html#delete/3"},{"type":"function","title":"Examples - Kadabra.delete/3","doc":"iex> {:ok, pid} = Kadabra.open(~c\"https://http2.codedge.dev\")\n    iex> Kadabra.delete(pid, \"/\")\n    :ok\n    iex> stream = receive do\n    ...>   {:end_stream, stream} -> stream\n    ...> end\n    iex> stream.status\n    200","ref":"Kadabra.html#delete/3-examples"},{"type":"function","title":"Kadabra.get/3","doc":"Makes a GET request.","ref":"Kadabra.html#get/3"},{"type":"function","title":"Examples - Kadabra.get/3","doc":"iex> {:ok, pid} = Kadabra.open(~c\"https://http2.codedge.dev\")\n    iex> Kadabra.get(pid, \"/\")\n    :ok\n    iex> response = receive do\n    ...>   {:end_stream, response} -> response\n    ...> end\n    iex> {response.id, response.status, response.body}\n    {1, 200, \"GET OK\"}","ref":"Kadabra.html#get/3-examples"},{"type":"function","title":"Kadabra.head/3","doc":"Makes a HEAD request.","ref":"Kadabra.html#head/3"},{"type":"function","title":"Examples - Kadabra.head/3","doc":"iex> {:ok, pid} = Kadabra.open(~c\"https://http2.codedge.dev\")\n    iex> Kadabra.head(pid, \"/\")\n    :ok\n    iex> response = receive do\n    ...>   {:end_stream, response} -> response\n    ...> end\n    iex> {response.id, response.status, response.body}\n    {1, 200, \"\"}","ref":"Kadabra.html#head/3-examples"},{"type":"function","title":"Kadabra.open/2","doc":"Opens a new connection.","ref":"Kadabra.html#open/2"},{"type":"function","title":"Examples - Kadabra.open/2","doc":"iex> {:ok, pid} = Kadabra.open(\"http://http2.codedge.dev\")\n    iex> is_pid(pid)\n    true\n\n    iex> {:ok, pid} = Kadabra.open(\"https://http2.codedge.dev\")\n    iex> is_pid(pid)\n    true","ref":"Kadabra.html#open/2-examples"},{"type":"function","title":"Kadabra.ping/1","doc":"Pings an existing connection.","ref":"Kadabra.html#ping/1"},{"type":"function","title":"Examples - Kadabra.ping/1","doc":"iex> {:ok, pid} = Kadabra.open(~c\"https://http2.codedge.dev\")\n    iex> Kadabra.ping(pid)\n    iex> receive do\n    ...>   {:pong, _pid} -> \"got pong!\"\n    ...> end\n    \"got pong!\"","ref":"Kadabra.html#ping/1-examples"},{"type":"function","title":"Kadabra.post/3","doc":"Makes a POST request.","ref":"Kadabra.html#post/3"},{"type":"function","title":"Examples - Kadabra.post/3","doc":"iex> {:ok, pid} = Kadabra.open(~c\"https://http2.codedge.dev\")\n    iex> Kadabra.post(pid, \"/\", body: \"test=123\")\n    :ok\n    iex> response = receive do\n    ...>   {:end_stream, response} -> response\n    ...> end\n    iex> {response.id, response.status}\n    {1, 200}","ref":"Kadabra.html#post/3-examples"},{"type":"function","title":"Kadabra.put/3","doc":"Makes a PUT request.","ref":"Kadabra.html#put/3"},{"type":"function","title":"Examples - Kadabra.put/3","doc":"iex> {:ok, pid} = Kadabra.open(~c\"https://http2.codedge.dev\")\n    iex> Kadabra.put(pid, \"/\", body: \"test\")\n    :ok\n    iex> stream = receive do\n    ...>   {:end_stream, stream} -> stream\n    ...> end\n    iex> stream.status\n    200","ref":"Kadabra.html#put/3-examples"},{"type":"function","title":"Kadabra.request/2","doc":"Makes a request with given headers and optional body.","ref":"Kadabra.html#request/2"},{"type":"function","title":"Examples - Kadabra.request/2","doc":"iex> {:ok, pid} = Kadabra.open(~c\"https://http2.codedge.dev\")\n    iex> path = \"/ECHO\" # Route echoes PUT body in uppercase\n    iex> body = \"sample echo request\"\n    iex> headers = [\n    ...>   {\":method\", \"PUT\"},\n    ...>   {\":path\", path},\n    ...> ]\n    iex> Kadabra.request(pid, headers: headers, body: body)\n    iex> response = receive do\n    ...>   {:end_stream, %Kadabra.Stream.Response{} = response} -> response\n    ...> after 5_000 -> :timed_out\n    ...> end\n    iex> {response.id, response.status, response.body}\n    {1, 200, \"SAMPLE ECHO REQUEST\"}","ref":"Kadabra.html#request/2-examples"},{"type":"type","title":"Kadabra.conn_opts/0","doc":"Options for connections.\n\n- `:ssl` - Specify custom options for `:ssl.connect/3`\n  when used with `:https` scheme.\n- `:tcp` - Specify custom options for `:gen_tcp.connect/3`\n  when used with `:http` scheme.","ref":"Kadabra.html#t:conn_opts/0"},{"type":"type","title":"Kadabra.request_opts/0","doc":"Options for making requests.\n\n- `:headers` - (Required) Headers for request.\n- `:body` - (Optional) Used for requests that can have a body, such as POST.\n- `:on_response` - (Optional) Async callback for handling stream response.","ref":"Kadabra.html#t:request_opts/0"},{"type":"type","title":"Kadabra.uri/0","doc":"","ref":"Kadabra.html#t:uri/0"},{"type":"module","title":"Kadabra.Request","doc":"Struct to encapsulate Kadabra requests.\n\nUseful when queueing multiple requests at once through\n`Kadabra.request/2`","ref":"Kadabra.Request.html"},{"type":"function","title":"Kadabra.Request.new/1","doc":"Returns a new `Kadabra.Request` struct from given opts.","ref":"Kadabra.Request.html#new/1"},{"type":"function","title":"Examples - Kadabra.Request.new/1","doc":"iex> Kadabra.Request.new([\n    ...>   headers: [{\":method\", \"GET\"}, {\"path\", \"/\"}],\n    ...>   body: \"\",\n    ...>   on_response: &IO.inspect/1\n    ...> ])\n    %Kadabra.Request{\n      headers: [{\":method\", \"GET\"}, {\"path\", \"/\"}],\n      body: \"\",\n      on_response: &IO.inspect/1\n    }","ref":"Kadabra.Request.html#new/1-examples"},{"type":"type","title":"Kadabra.Request.t/0","doc":"","ref":"Kadabra.Request.html#t:t/0"},{"type":"module","title":"Kadabra.Stream.Response","doc":"Response struct returned from open streams.\n\nIf received as a push promise, `:status` and `:body` will\nmost likely be empty.\n\n*Sample response for a `PUT` request*\n\n    %Kadabra.Stream.Response{\n      body: \"SAMPLE ECHO REQUEST\",\n      headers: [\n        {\":status\", \"200\"},\n        {\"content-type\", \"text/plain; charset=utf-8\"},\n        {\"date\", \"Sun, 16 Oct 2016 21:28:15 GMT\"}\n      ],\n      id: 1,\n      status: 200\n    }","ref":"Kadabra.Stream.Response.html"},{"type":"function","title":"Kadabra.Stream.Response.get_header/2","doc":"Fetches header with given name.","ref":"Kadabra.Stream.Response.html#get_header/2"},{"type":"function","title":"Examples - Kadabra.Stream.Response.get_header/2","doc":"iex> stream = %Kadabra.Stream.Response{headers: [{\":status\", \"200\"}]}\n    iex> Kadabra.Stream.Response.get_header(stream.headers, \":status\")\n    {\":status\", \"200\"}","ref":"Kadabra.Stream.Response.html#get_header/2-examples"},{"type":"type","title":"Kadabra.Stream.Response.t/0","doc":"","ref":"Kadabra.Stream.Response.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.6.1 - Changelog","doc":"**Fixed**\n\n- Removed Elixir compile warnings.","ref":"changelog.html#v0-6-1"},{"type":"extras","title":"v0.6.0 - Changelog","doc":"**Security**\n\n- Verify CA certificates with `:certifi` (~> 2.5) by default. This is considered a breaking change\n  for anyone using Kadabra for anything other than [Pigeon](https://github.com/codedge-llc/pigeon).","ref":"changelog.html#v0-6-0"},{"type":"extras","title":"v0.5.0 - Changelog","doc":"**Changed**\n\n- Minimum Elixir version bumped to 1.6.\n\n**Fixed**\n\n- Removed Elixir 1.11 compile warnings.","ref":"changelog.html#v0-5-0"},{"type":"extras","title":"v0.4.5 - Changelog","doc":"- Removed some compile warnings.","ref":"changelog.html#v0-4-5"},{"type":"extras","title":"v0.4.4 - Changelog","doc":"- Fixed ArithmeticError when calculating how many streams to request\n  on infinite stream sets.","ref":"changelog.html#v0-4-4"},{"type":"extras","title":"v0.4.3 - Changelog","doc":"- Fixed supervisor crash report during normal connection shutdown.\n- Removed `GenStage` dependency.\n- GOAWAY error logger messages now disabled by default.\n  Re-enable with `config :kadabra, debug_log?: true`.","ref":"changelog.html#v0-4-3"},{"type":"extras","title":"v0.4.2 - Changelog","doc":"- Fixed `{:closed, pid}` task race condition during connection cleanup.\n- Everything is supervised under `Kadabra.Application` again, instead of\n  handling supervision yourself.","ref":"changelog.html#v0-4-2"},{"type":"extras","title":"v0.4.1 - Changelog","doc":"- Send exactly number of allowed bytes on initial connection WINDOW_UPDATE.\n- Default settings use maximum values for MAX_FRAME_SIZE and INITIAL_WINDOW_SIZE.\n- Incoming PING and WINDOW_UPDATE frames are now validated, closing the\n  connection if an error is encountered.\n- Fixed: can no longer accidentally send 0-size WINDOW_UPDATE frames.\n- Fixed: don't send WINDOW_UPDATE frames larger than remote server's available\n  connection flow window.","ref":"changelog.html#v0-4-1"},{"type":"extras","title":"v0.4.0 - Changelog","doc":"- Support for `http` URIs.\n- Requests are now buffered with GenStage.\n- Added `Kadabra.head/2` and `Kadabra.delete/2`.\n- `Kadabra.open/3` replaced with `Kadabra.open/2`.\n  - Scheme, host and port are now automatically parsed from the URI string.\n    See the README for examples.\n  - Socket options passed as `:tcp`/`:ssl`, respectively.\n- Removed `:reconnect` functionality.","ref":"changelog.html#v0-4-0"},{"type":"extras","title":"v0.3.8 - Changelog","doc":"- Fixed: Streams properly killed if hpack table crashes.\n- Removed unused `Scribe` dependency.","ref":"changelog.html#v0-3-8"},{"type":"extras","title":"v0.3.7 - Changelog","doc":"- Fixed: `noproc` crash caused by race condition on recv GOAWAY.","ref":"changelog.html#v0-3-7"},{"type":"extras","title":"v0.3.6 - Changelog","doc":"- Fixed: ES flag properly set on certain HEADERS frames.","ref":"changelog.html#v0-3-6"},{"type":"extras","title":"v0.3.5 - Changelog","doc":"- Fixed: Memory leak on connection crashes.\n- New supervision structure. `Kadabra.open/2` now returns a supervisor pid,\n  but the API for making requests remains unchanged.","ref":"changelog.html#v0-3-5"},{"type":"extras","title":"v0.3.4 - Changelog","doc":"- Fixed: Connections properly respect settings updates.","ref":"changelog.html#v0-3-4"},{"type":"extras","title":"v0.3.3 - Changelog","doc":"- Fixed: Hpack memory leak on connection close.","ref":"changelog.html#v0-3-3"},{"type":"extras","title":"v0.3.2 - Changelog","doc":"- Fixed: Connection settings defaults are now actually default.","ref":"changelog.html#v0-3-2"},{"type":"extras","title":"v0.3.1 - Changelog","doc":"- Fixed: Sending payloads larger than the stream window.","ref":"changelog.html#v0-3-1"},{"type":"extras","title":"v0.3.0 - Changelog","doc":"- Minimum requirements are now Elixir 1.4/OTP 19.\n- Performance improvements for individual streams.\n- Fixed: multiple connections now supported per host.\n- Request responses now return with new `%Stream.Response{}` struct.\n- Push promises can be intercepted with `{:push_promise, %Stream.Response{}}`\n  messages.","ref":"changelog.html#v0-3-0"},{"type":"extras","title":"v0.2.2 - Changelog","doc":"- `Connection` now respects `max_concurrent_streams`.\n- Fixed: proper WINDOW_UPDATE responses on received DATA frames.","ref":"changelog.html#v0-2-2"},{"type":"extras","title":"v0.2.1 - Changelog","doc":"- Fixed: calling `Kadabra.open/3` with `reconnect: false` to disable\n  automatic reconnect on socket close.","ref":"changelog.html#v0-2-1"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}